Learn R Programming

flightsbr (version 1.1.1)

generate_all_months: Generate all months with yyyymm format for a given year

Description

Generate all months with yyyymm format for a given year

Usage

generate_all_months(date)

Value

Vector or strings.

Arguments

date

Numeric. 4-digit date in the format yyyy. The function also takes multiple years.

Examples

Run this code
if (FALSE)  if (interactive()) {
# Generate all months in 2000
a <- check_date(2000)

b <- check_date(c(2000, 2005))
}

Run the code above in your browser using DataLab