Learn R Programming

flightsbr (version 1.1.1)

get_aircraft_dates_available: Retrieve all dates available for aircraft data from ANAC website

Description

Retrieve all dates available for aircraft data from ANAC website

Usage

get_aircraft_dates_available()

Arguments

Value

Numeric vector.

Examples

Run this code
if (FALSE)  if (interactive()) {
# check dates
a <- get_aircraft_dates_available()
}

Run the code above in your browser using DataLab