Learn R Programming

flightsbr (version 1.1.1)

get_aircraft_url: Put together the url of aircraft data files

Description

Put together the url of aircraft data files

Usage

get_aircraft_url(date = parent.frame()$date)

Value

A url string.

Arguments

date

Numeric. Either a 6-digit date in the format yyyymm or a 4-digit date input yyyy. Defaults to NULL, in which case the function retrieves information for all years available.

Examples

Run this code
if (FALSE)  if (interactive()) {
# Generate url
a <- get_flights_url(year=2000, month=11)
}

Run the code above in your browser using DataLab