Learn R Programming

flightsbr (version 1.1.1)

get_airport_movements_url: Put together the url of airport movement data files

Description

Put together the url of airport movement data files

Usage

get_airport_movements_url(date = parent.frame()$date)

Value

A url string.

Arguments

date

Numeric. Date of the data in the format yyyymm. Defaults to 202001. To download the data for all months in a year, the user can pass a 4-digit year input yyyy. The parameter also accepts a vector of dates such as c(202001, 202006, 202012).

Examples

Run this code
if (FALSE)  if (interactive()) {
# Generate url
a <- get_airport_movements_url(year=2000, month=11)
}

Run the code above in your browser using DataLab