Learn R Programming

flightsbr (version 1.1.1)

latest_airfares_date: Check the date of the latest airfare data available

Description

Check the date of the latest airfare data available

Usage

latest_airfares_date(dom = TRUE)

Value

A numeric date in the format yyyymm.

Arguments

dom

Logical. Defaults to TRUE download airfares of domestic flights. If FALSE, the function downloads airfares of international flights.

See Also

Other support function: latest_flights_date()

Examples

Run this code
if (FALSE)  if (interactive()) {

latest_date <- latest_airfares_date()

}

Run the code above in your browser using DataLab