Learn R Programming

flightsbr (version 1.1.1)

latest_flights_date: Check the date of the latest flight data available

Description

Check the date of the latest flight data available

Usage

latest_flights_date()

Arguments

Value

A numeric date in the format yyyymm.

See Also

Other support function: latest_airfares_date()

Examples

Run this code
if (FALSE)  if (interactive()) {

latest_date <- latest_flights_date()

}

Run the code above in your browser using DataLab