Retrieve all dates available for airfares data from ANAC website
Source:R/utils_airfares.R
get_airfares_dates_available.RdRetrieve all dates available for airfares data from ANAC website
Arguments
- dom
Logical. Defaults to
TRUEdownload airfares of domestic flights. IfFALSE, the function downloads airfares of international flights.- cache
Logical. Whether the function should read cached data downloaded previously. Defaults to
TRUE. IfFALSE, the function will always download the data and overwrite cached data.
Examples
if (FALSE) if (interactive()) {
# check dates
a <- get_airfares_dates_available(domestic = TRUE)
} # \dontrun{}