Learn R Programming

flightsbr (version 1.1.1)

get_airfares_dates_available: Retrieve all dates available for airfares data from ANAC website

Description

Retrieve all dates available for airfares data from ANAC website

Usage

get_airfares_dates_available(dom)

Value

Numeric vector.

Arguments

dom

Logical. Defaults to TRUE download airfares of domestic flights. If FALSE, the function downloads airfares of international flights.

Examples

Run this code
if (FALSE)  if (interactive()) {
# check dates
a <- get_airfares_dates_available(domestic = TRUE)
}

Run the code above in your browser using DataLab