Learn R Programming

flightsbr (version 1.1.1)

get_airfares_url: Put together the url of airfare data files

Description

Put together the url of airfare data files

Usage

get_airfares_url(dom, date = parent.frame()$date)

Value

A url string.

Arguments

dom

Logical. Defaults to TRUE download airfares of domestic flights. If FALSE, the function downloads airfares of international flights.

date

Numeric. Date of the data in the format yyyymm. To download the data for all months in a year, the user can pass a 4-digit year input yyyy. The parameter also accepts a vector of dates such as c(202001, 202006, 202012).

Examples

Run this code
if (FALSE)  if (interactive()) {
# Generate url
a <- get_airfares_url(year=2002, month=11)
}

Run the code above in your browser using DataLab