powered by
Put together the url of airport movement data files
get_airport_movements_url(date = parent.frame()$date)
A url string.
Numeric. Date of the data in the format yyyymm. Defaults to 202001. To download the data for all months in a year, the user can pass a 4-digit year input yyyy. The parameter also accepts a vector of dates such as c(202001, 202006, 202012).
yyyymm
202001
yyyy
c(202001, 202006, 202012)
if (FALSE) if (interactive()) { # Generate url a <- get_airport_movements_url(year=2000, month=11) }
Run the code above in your browser using DataLab