Retrieve all dates available for flights data from ANAC website
Source:R/utils_flights.R
get_flight_dates_available.RdRetrieve all dates available for flights data from ANAC website
Arguments
- type
String. Whether the data set should be of the type
basica(flight stage, the default) orcombinada(On flight origin and destination - OFOD).- cache
Logical. Whether the function should read cached data downloaded previously. Defaults to
TRUE. IfFALSE, the function will always download the data and overwrite cached data.
Examples
if (FALSE) if (interactive()) {
# check dates
a <- get_flight_dates_available()
} # \dontrun{}