A "data.table" "data.frame" object. All columns are returned with
class of type "character".
Arguments
date
Numeric. Date of the data in the format yyyymm. Defaults to
the latest date available. To download the data for all months in
a year, the user can pass a 4-digit year input yyyy. The
function also accepts a vector of dates, like c(202201, 202301)
or c(2022, 2024).
domestic
Logical. Defaults to TRUE download airfares of domestic
flights. If FALSE, the function downloads airfares of
international flights.
showProgress
Logical. Defaults to TRUE display progress.
select
A vector of column names or positions to keep. The rest of the
columns are not read. The order that the columns passed determines the
order of the columns in the result.
cache
Logical. Whether the function should read cached data downloaded
previously. Defaults to TRUE. If FALSE, the function will
always download the data and overwrite cached data.